==> nidx_binding-6.3.0.post10.tar.gz: nidx_binding-6.3.0.post10/src/tool.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

use std::{fs::File, path::PathBuf};

use crate::{import_export, settings::EnvSettings, Settings};

#[derive(Debug, clap::Subcommand)]
pub enum ToolCommand {
    Import {
        file: PathBuf,
    },
}

#[derive(Debug, clap::Subcommand)]
pub enum ImportCommand {
    File {
        file: PathBuf,
    },
    Stdin,
}

pub async fn run_tool(settings: &EnvSettings, cmd: ToolCommand) -> anyhow::Result<()> {
    match cmd {
        ToolCommand::Import {
            file,
        } => run_import(settings, file).await,
    }
}

async fn run_import(settings: &EnvSettings, file: PathBuf) -> anyhow::Result<()> {
    let settings = Settings::from_env_settings(settings.clone()).await?;

    if file.as_os_str() == "-" {
        import_export::import_shard(
            settings.metadata.clone(),
            settings.storage.as_ref().unwrap().object_store.clone(),
            std::io::stdin(),
        )
        .await?;
    } else {
        import_export::import_shard(
            settings.metadata.clone(),
            settings.storage.as_ref().unwrap().object_store.clone(),
            File::open(file)?,
        )
        .await?;
    };
    println!("Import successful");

    Ok(())
}

==> nidx_binding-6.3.1.post48.tar.gz: nidx_binding-6.3.1.post48/src/tool.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

use std::{fs::File, path::PathBuf};

use crate::{Settings, import_export, settings::EnvSettings};

#[derive(Debug, clap::Subcommand)]
pub enum ToolCommand {
    Import { file: PathBuf },
}

#[derive(Debug, clap::Subcommand)]
pub enum ImportCommand {
    File { file: PathBuf },
    Stdin,
}

pub async fn run_tool(settings: &EnvSettings, cmd: ToolCommand) -> anyhow::Result<()> {
    match cmd {
        ToolCommand::Import { file } => run_import(settings, file).await,
    }
}

async fn run_import(settings: &EnvSettings, file: PathBuf) -> anyhow::Result<()> {
    let settings = Settings::from_env_settings(settings.clone()).await?;

    if file.as_os_str() == "-" {
        import_export::import_shard(
            settings.metadata.clone(),
            settings.storage.as_ref().unwrap().object_store.clone(),
            std::io::stdin(),
        )
        .await?;
    } else {
        import_export::import_shard(
            settings.metadata.clone(),
            settings.storage.as_ref().unwrap().object_store.clone(),
            File::open(file)?,
        )
        .await?;
    };
    println!("Import successful");

    Ok(())
}
